@@ -21,7 +21,7 @@
 #' }
 #'
 rprintv <- function(x,...) {
-  args <- list(...)
+  args <- makelist(...)
   x <- stringr::str_replace_all(x,"%","%%")
   xs <- unlist(stringr::str_extract_all(x,stringr::perl("(?<!\\$)\\$\\w+(:[\\s\\+\\-\\#\\.\\d]*\\w)?")))
   xss <- stringr::str_replace_all(xs,stringr::perl("(?<!\\$)\\$(\\w+)(:[\\s\\+\\-\\#\\.\\d]*\\w)?"),"\\1")
